@@ -4,7 +4,7 @@ Main interface for mediapackage service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_mediapackage import (
         Client,
         ListChannelsPaginator,
@@ -13,10 +13,8 @@ Usage::
         MediaPackageClient,
     )
 
-    session = boto3.Session()
-
-    client: MediaPackageClient = boto3.client("mediapackage")
-    session_client: MediaPackageClient = session.client("mediapackage")
+    session = Session()
+    client: MediaPackageClient = session.client("mediapackage")
 
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_harvest_jobs_paginator: ListHarvestJobsPaginator = client.get_paginator("list_harvest_jobs")
