@@ -1,7 +1,7 @@
 """
 Type annotations for mediapackage service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/literals/)
 
 Usage::
 
@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -38,8 +38,11 @@ __all__ = (
     "StatusType",
     "StreamOrderType",
     "UtcTimingType",
+    "MediaPackageServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -65,13 +68,14 @@ PeriodTriggersElementType = Literal["ADS"]
 PlaylistTypeType = Literal["EVENT", "NONE", "VOD"]
 PresetSpeke20AudioType = Literal["PRESET-AUDIO-1"]
 PresetSpeke20VideoType = Literal["PRESET-VIDEO-1"]
-ProfileType = Literal["HBBTV_1_5", "NONE"]
+ProfileType = Literal["DVB_DASH_2014", "HBBTV_1_5", "HYBRIDCAST", "NONE"]
 SegmentTemplateFormatType = Literal[
     "NUMBER_WITH_DURATION", "NUMBER_WITH_TIMELINE", "TIME_WITH_TIMELINE"
 ]
 StatusType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED"]
 StreamOrderType = Literal["ORIGINAL", "VIDEO_BITRATE_ASCENDING", "VIDEO_BITRATE_DESCENDING"]
-UtcTimingType = Literal["HTTP-HEAD", "HTTP-ISO", "NONE"]
+UtcTimingType = Literal["HTTP-HEAD", "HTTP-ISO", "HTTP-XSDATE", "NONE"]
+MediaPackageServiceName = Literal["mediapackage"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -81,10 +85,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -99,12 +105,16 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -152,6 +162,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -173,6 +184,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -183,9 +195,11 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
@@ -198,6 +212,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -211,11 +226,14 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -256,7 +274,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -270,6 +290,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -277,6 +298,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -284,11 +306,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -298,6 +322,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -355,6 +380,36 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_channels", "list_harvest_jobs", "list_origin_endpoints"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
