@@ -1,7 +1,7 @@
 """
 Type annotations for mediapackage service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/type_defs/)
 
 Usage::
 
@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
     AdMarkersType,
@@ -29,11 +29,11 @@ from .literals import (
     UtcTimingType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -73,10 +73,13 @@ __all__ = (
     "HlsPackageTypeDef",
     "IngestEndpointTypeDef",
     "IngressAccessLogsTypeDef",
+    "ListChannelsRequestListChannelsPaginateTypeDef",
     "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListHarvestJobsRequestListHarvestJobsPaginateTypeDef",
     "ListHarvestJobsRequestRequestTypeDef",
     "ListHarvestJobsResponseTypeDef",
+    "ListOriginEndpointsRequestListOriginEndpointsPaginateTypeDef",
     "ListOriginEndpointsRequestRequestTypeDef",
     "ListOriginEndpointsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -575,6 +578,7 @@ HlsPackageTypeDef = TypedDict(
         "AdTriggers": Sequence[AdTriggersElementType],
         "AdsOnDeliveryRestrictions": AdsOnDeliveryRestrictionsType,
         "Encryption": "HlsEncryptionTypeDef",
+        "IncludeDvbSubtitles": bool,
         "IncludeIframeOnlyStream": bool,
         "PlaylistType": PlaylistTypeType,
         "PlaylistWindowSeconds": int,
@@ -605,6 +609,14 @@ IngressAccessLogsTypeDef = TypedDict(
     total=False,
 )
 
+ListChannelsRequestListChannelsPaginateTypeDef = TypedDict(
+    "ListChannelsRequestListChannelsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListChannelsRequestRequestTypeDef = TypedDict(
     "ListChannelsRequestRequestTypeDef",
     {
@@ -623,6 +635,16 @@ ListChannelsResponseTypeDef = TypedDict(
     },
 )
 
+ListHarvestJobsRequestListHarvestJobsPaginateTypeDef = TypedDict(
+    "ListHarvestJobsRequestListHarvestJobsPaginateTypeDef",
+    {
+        "IncludeChannelId": str,
+        "IncludeStatus": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListHarvestJobsRequestRequestTypeDef = TypedDict(
     "ListHarvestJobsRequestRequestTypeDef",
     {
@@ -643,6 +665,15 @@ ListHarvestJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListOriginEndpointsRequestListOriginEndpointsPaginateTypeDef = TypedDict(
+    "ListOriginEndpointsRequestListOriginEndpointsPaginateTypeDef",
+    {
+        "ChannelId": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListOriginEndpointsRequestRequestTypeDef = TypedDict(
     "ListOriginEndpointsRequestRequestTypeDef",
     {
@@ -734,7 +765,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
